# Copyright (C) 2020-2023 MicroSys Electronics GmbH
# Author: Kay Potthoff <kay.potthoff@microsys.de>

inherit microsys

FILESEXTRAPATHS_prepend := "${THISDIR}/${PN}:"
PATCHTOOL = "git"
PATCH_COMMIT_FUNCTIONS = "1"

#URL    = "git://github.com/MicroSysElectronics/linux;protocol=https"
#BRANCH = "microsys-s32-bsp34.0"
#SRCREV = "9ec3971b5b38650f57ae1d49f105e568ce9633ed"

SRC_URI += "file://linux.patch"

python do_patch_prepend() {
    if d.getVar('PATCHTOOL') == 'git':
        srcsubdir = d.getVar('S')
        bb.process.run('git config am.threeWay true', cwd=srcsubdir)
        bb.process.run('git config am.keepcr true', cwd=srcsubdir)
        bb.process.run('git config apply.whitespace fix', cwd=srcsubdir)
        bb.process.run('git config apply.ignoreWhitespace change', cwd=srcsubdir)
}

PLATFORM ?= "${MACHINE}"
ITS_FILE ?= "${@microsys_get_its_file(d)}"

SCMVERSION = "n"

do_install[depends] += "u-boot-tools-native:do_populate_sysroot"

INSTALL_MOD_PATH = "${D}"
EXTRA_OEMAKE += 'INSTALL_MOD_PATH="${D}"'

KERNEL_ALT_IMAGETYPE += "Image.gz"

KERNEL_MODULE_AUTOLOAD_mpxs32g += "\
    nxp \
"

LINUX_TOOLS ?= "gpio leds spi usb"

do_compile_append() {

    its_file=${ITS_FILE} # ${S}/kernel-${PLATFORM}.its

    if [ ! -f ${its_file} ]; then
        its_file = ${S}/kernel-mpxls10xx.its
    fi
    default="            default = \"${ITS_DEVICETREE_CFG}\";"
    if [ -n "${ITS_DEVICETREE_CFG}" ]; then
        sed -e "s/^ *default *=.*$/${default}/g" ${its_file} > ${B}/kernel-${PLATFORM}.its
    else
        cp ${its_file} ${B}/kernel-${PLATFORM}.its
    fi

    # Build Linux tools

    cd ${S}
    oe_runmake -C tools/ ${LINUX_TOOLS}
}

do_install_append() {
    if [ -f "arch/${ARCH}/boot/Image" ]; then
        install -m 0644 -o root -g root arch/${ARCH}/boot/Image ${D}/boot/Image-${KERNEL_VERSION}
        ln -sf  Image-${KERNEL_VERSION} ${D}/boot/Image
    fi
    if [ -f "arch/${ARCH}/boot/Image.gz" ]; then
        install -m 0644 -o root -g root arch/${ARCH}/boot/Image.gz ${D}/boot/Image-${KERNEL_VERSION}.gz
        ln -sf  Image-${KERNEL_VERSION}.gz ${D}/boot/Image.gz
    fi
    mkimage -f kernel-${PLATFORM}.its fitImage.itb
    install -m 0644 -o root -g root fitImage.itb ${D}/boot/fitImage-${KERNEL_VERSION}.itb
    ln -sf fitImage-${KERNEL_VERSION}.itb ${D}/boot/fitImage.itb

    bbdebug 1 "Installing fitImage-${KERNEL_VERSION}.itb\n"
    install -d ${DEPLOY_DIR_IMAGE}
    install -m 0644 ${D}/boot/fitImage-${KERNEL_VERSION}.itb ${DEPLOY_DIR_IMAGE}/fitImage-${KERNEL_VERSION}.itb
    ln -sf fitImage-${KERNEL_VERSION}.itb ${DEPLOY_DIR_IMAGE}/fitImage.itb

    # Install Linux tools
    # (the Makefile in tools/ doesn't install the tools with root ownership
    # therefore, we're doing this manually here)

    install -d -o root -g root ${D}/usr/bin
    install -m 0755 -o root -g root ${S}/tools/gpio/lsgpio ${D}/usr/bin
    install -m 0755 -o root -g root ${S}/tools/gpio/gpio-event-mon ${D}/usr/bin
    install -m 0755 -o root -g root ${S}/tools/gpio/gpio-hammer ${D}/usr/bin
    install -m 0755 -o root -g root ${S}/tools/leds/uledmon ${D}/usr/bin
    install -m 0755 -o root -g root ${S}/tools/usb/testusb ${D}/usr/bin
    install -m 0755 -o root -g root ${S}/tools/spi/spidev_test ${D}/usr/bin

}

do_deploy_append() {
    bbdebug 1 "Deploying fitImage-${KERNEL_VERSION}.itb\n"
    install -d ${DEPLOY_DIR_IMAGE}
    install -m 0644 ${D}/boot/fitImage-${KERNEL_VERSION}.itb ${DEPLOY_DIR_IMAGE}/fitImage-${KERNEL_VERSION}.itb
    ln -sf fitImage-${KERNEL_VERSION}.itb ${DEPLOY_DIR_IMAGE}/fitImage.itb
}

FILES_${KERNEL_PACKAGE_NAME}-image += "/boot/Image*"
FILES_${KERNEL_PACKAGE_NAME}-image-fitimage += "/boot/fitImage*"

PACKAGES += "${PN}-images"
FILES_${PN}-images += "/boot"
#COMPATIBLE_MACHINE = "(s32)"

FILES_${PN} += "/boot/fitImage*"

PACKAGES += "${PN}-tools"
FILES_${PN}-tools += " \
   /usr/bin \
"
INSANE_SKIP_${PN}-tools = "ldflags debug-files"
