# Copyright (C) 2020-2021 MicroSys Electronics GmbH
# Author: Kay Potthoff <kay.potthoff@microsys.de>

inherit microsys

FILESEXTRAPATHS_prepend := "${THISDIR}/${PN}:"

NXP_FIRMWARE_LOCAL_DIR := "${THISDIR}/${PN}"

LIC_FILES_CHKSUM += "file://PFE-License.txt;md5=3efaacbb2298460a2345c5950a9ebb6a"

COMPATIBLE_MACHINE_append = "|mpxs32g"

do_compile[depends] += "virtual/kernel:do_deploy"

SRC_URI := "${@microsys_var_remove(d, 'SRC_URI', '.*\\bNXP_FIRMWARE_LOCAL_DIR\\b.*')}"

SRC_URI += "file://0001-linux-pfeng-pfeng-phylink-fixed-SGMII-AN.patch"
SRC_URI += "file://0003-sw-linux-phylink-fixed-SGMII-AN-feature.patch"

do_patch_append() {
    import shutil

    shutil.copy2(os.path.join(d.getVar("NXP_FIRMWARE_LOCAL_DIR"),
                              "PFE-License.txt"),
                 os.path.join(d.getVar("S"), "PFE-License.txt"))

    class_name = os.path.join(d.getVar("S"), d.getVar("FW_INSTALL_CLASS_NAME"))
    util_name = os.path.join(d.getVar("S"), d.getVar("FW_INSTALL_UTIL_NAME"))

    shutil.copy2(os.path.join(d.getVar("NXP_FIRMWARE_LOCAL_DIR"),
                              d.getVar("PFE_FW_CLASS_BIN")),
                 class_name)

    shutil.copy2(os.path.join(d.getVar("NXP_FIRMWARE_LOCAL_DIR"),
                              d.getVar("PFE_FW_UTIL_BIN")),
                 util_name)

    os.chmod(class_name, 0o0644)
    os.chmod(util_name, 0o0644)
}

module_do_install() {
    mkdir -p ${INSTALL_DIR}
    install -D "${MDIR}/pfeng.ko" "${INSTALL_DIR}/pfeng.ko"
    mkdir -p "${FW_INSTALL_DIR}"
    install -D -m 0644 "${NXP_FIRMWARE_LOCAL_DIR}/${PFE_FW_CLASS_BIN}" "${FW_INSTALL_DIR}/${FW_INSTALL_CLASS_NAME}"
    install -D -m 0644 "${NXP_FIRMWARE_LOCAL_DIR}/${PFE_FW_UTIL_BIN}" "${FW_INSTALL_DIR}/${FW_INSTALL_UTIL_NAME}"
    install -D -m 0644 "${NXP_FIRMWARE_LOCAL_DIR}/${PFE_FW_CLASS_BIN}" "${D}/${FW_INSTALL_CLASS_NAME}"
    install -D -m 0644 "${NXP_FIRMWARE_LOCAL_DIR}/${PFE_FW_UTIL_BIN}" "${D}/${FW_INSTALL_UTIL_NAME}"
}

FILES_${PN} += "/${FW_INSTALL_CLASS_NAME} /${FW_INSTALL_UTIL_NAME}"

# This is a workaround for the build error
# "basehash value changed"
do_populate_sysroot[vardepsexclude] += "PROVIDES"
do_populate_setscene[vardepsexclude] += "PROVIDES"
do_package[vardepsexclude] += "PROVIDES RPROVIDES_${PN}"
